.. image:: https://raw.githubusercontent.com/molassesapp/molasses-go/main/logo.png
        :width: 200 px
        :height: 200 px
        :target: https://molasses.app

===============
molasses-python
===============

.. image:: https://img.shields.io/pypi/v/molasse.svg
        :target: https://pypi.python.org/pypi/molasses

.. image:: https://pyup.io/repos/github/molassesapp/molasses_python/shield.svg
     :target: https://pyup.io/repos/github/molassesapp/molasses_python/
     :alt: Updates



Molasses python SDK for feature flags


* Free software: MIT license

Install
-------

.. code:: python

  pip install molasses


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
